Struct libp2p_pnet::PreSharedKey [−][src]
pub struct PreSharedKey(_);
A pre-shared key, consisting of 32 bytes of random data.
Implementations
impl PreSharedKey[src]
impl PreSharedKey[src]pub fn fingerprint(&self) -> Fingerprint[src]
pub fn fingerprint(&self) -> Fingerprint[src]Compute PreSharedKey fingerprint identical to the go-libp2p fingerprint. The computation of the fingerprint is not specified in the spec.
This provides a way to check that private keys are properly configured without dumping the key itself to the console.